@@ -27,34 +27,36 @@
 #' @export
 
 plot.realtime <- function(x = NULL, Parameter = c("Flow","Level"), ...){
-  #browser()
-  rldf = x
+
   
   Parameter <- match.arg(Parameter)
   
-  if(length(unique(rldf$STATION_NUMBER)) > 1L) {
+  if(length(unique(x$STATION_NUMBER)) > 1L) {
     stop("realtime plot methods only work with objects that contain one station", call. = FALSE)
   }
 
-  if(is.null(rldf)) stop("Station(s) not present in the datamart")
+  if(is.null(x)) stop("Station(s) not present in the datamart")
+
+  ## Catch mis labelled parameter
+  if (Parameter == "Level" && ((nrow(x[x$Parameter == "Level",]) == 0) |  all(is.na(x[x$Parameter == "Level",]$Value)))) {
+    stop(paste0(unique(x$STATION_NUMBER)," is likely a flow station. Try setting Parameter = 'Flow'"), call. = FALSE)
+  }
   
-  ## Is there any NA's in the flow data?
-  if(any(is.na(rldf[rldf$Parameter == "Flow",]$Value)) & Parameter == "Flow"){
-    rldf <- rldf[rldf$Parameter == "Level",]
-    message(paste0(rldf$STATION_NUMBER," is lake level station. Defaulting Parameter = 'Level'"))
+  if (Parameter == "Flow" && ((nrow(x[x$Parameter == "Flow",]) == 0) |  all(is.na(x[x$Parameter == "Flow",]$Value)))) {
+    stop(paste0(unique(x$STATION_NUMBER)," is likely a lake level station. Try setting Parameter = 'Level'"), call. = FALSE)
   } else{
-    rldf <- rldf[rldf$Parameter == Parameter,]
+    x <- x[x$Parameter == Parameter,]
   }
   
   
   
   
   ## Join with meta data to get station name
-  rldf <- dplyr::left_join(rldf, tidyhydat::allstations, by = c("STATION_NUMBER","PROV_TERR_STATE_LOC"))
+  x <- dplyr::left_join(x, tidyhydat::allstations, by = c("STATION_NUMBER","PROV_TERR_STATE_LOC"))
   
-  rldf$STATION <- paste(rldf$STATION_NAME, rldf$STATION_NUMBER, sep = " - ")
+  x$STATION <- paste(x$STATION_NAME, x$STATION_NUMBER, sep = " - ")
   
-  rldf$STATION <- factor(rldf$STATION)
+  x$STATION <- factor(x$STATION)
   
   graphics::par(mar = c(4, 5, 2, 1), 
                 mgp = c(3.1, 0.4, 0), 
@@ -63,25 +65,25 @@ plot.realtime <- function(x = NULL, Parameter = c("Flow","Level"), ...){
                 xaxs = "i", yaxs = "i") 
   
   graphics::plot(Value ~ Date,
-                 data = rldf,
+                 data = x,
                  xlab = "Date", 
-                 ylab = eval(parse(text = label_helper(unique(rldf$Parameter)))),
+                 ylab = eval(parse(text = label_helper(unique(x$Parameter)))),
                  axes = FALSE,
                  col = "#82D6FF96",
-                 #ylim = c(min(rldf$Value, na.rm = TRUE), max(rldf$Value, na.rm = TRUE) + 2),
+                 #ylim = c(min(x$Value, na.rm = TRUE), max(x$Value, na.rm = TRUE) + 2),
                  pch = 20, 
                  cex = 0.75,
                  frame.plot = TRUE,
                  ...)
   
-  at_y = utils::tail(utils::head(pretty(rldf$Value), -1), -1)
+  at_y = utils::tail(utils::head(pretty(x$Value), -1), -1)
   graphics::mtext(side = 2, text = at_y, at = at_y, 
         col = "grey20", line = 1, cex = 1)
   
-  at_x = utils::tail(utils::head(pretty(rldf$Date), -1), -1)
+  at_x = utils::tail(utils::head(pretty(x$Date), -1), -1)
   graphics::mtext(side = 1, text = format(at_x, "%b-%d"), at = at_x, col = "grey20", line = 1, cex = 1)
   
-  graphics::title(main=paste0(unique(rldf$STATION)), cex.main = 1.1)
+  graphics::title(main=paste0(unique(x$STATION)), cex.main = 1.1)
   
   
   
