@@ -31,3 +31,10 @@ test_that("When station_number is ALL there is an error", {
   skip_on_cran()
   expect_error(realtime_dd(station_number = "ALL"))
 })
+
+test_that("realtime_dd works when station is not realtime",{
+  skip_on_cran()
+  stns <- hy_stations(hydat_path = hy_test_db())
+  stn <- sample(stns$STATION_NUMBER[!stns$REAL_TIME & stns$HYD_STATUS == "DISCONTINUED"], 1)
+  expect_s3_class(realtime_dd(stn), "realtime")
+})
