@@ -48,5 +48,5 @@ test_that("province in any case is accepted",{
 
 test_that("'CA' to prov_terr_state_loc argument returns only Canadian stations",{
   only_canada <- unique(hy_stations(prov_terr_state_loc = "CA", hydat_path = hy_test_db())$PROV_TERR_STATE_LOC)
-  expect_equal(c("NB", "AB", "YT", "BC"), only_canada)
+  expect_equal(c("NB", "AB", "SK", "YT", "BC"), only_canada)
 })
